@@ -1,4 +1,36 @@
 
+
+#' impute gradients from two vectors with x and y coordinates.
+#' @export
+#' @param x A vector of x coordinates
+#' @param y A corresponding vector of y coordinates
+#' @param edgeGradients This gives the options of specifing the gradients at either edge of the domain. By default this is c(NA,NA) meaning that the defaults from the original paper are used. If this is set to c(0,NA) for instance this will mean that the left edge gradient is zero and the right edge gradient is as recommended in the original paper. This setting has no impact if a full set of gradients is input.
+#' @references Schumaker, L.L. 1983. On shape-preserving quadratic spline interpolation. SIAM Journal of Numerical Analysis 20: 854-64.
+#' @references Judd (1998). Numerical Methods in Economics. MIT Press
+#'
+#' @examples
+#' x = seq(1,6)
+#' y = log(x)
+#' grads = impute_gradients(x, y)
+impute_gradients = function(x,y, edgeGradients = c(NA,NA)){
+  n = length(x)
+  # Judd (1998), page 233, second last equation
+  L = sqrt( (x[2:n]-x[1:(n-1)])^2 + (y[2:n]-y[1:(n-1)])^2)
+  # Judd (1998), page 233, last equation
+  d = (y[2:n]-y[1:(n-1)])/(x[2:n]-x[1:(n-1)])
+  # Judd (1998), page 234, Eqn 6.11.6
+  Conditionsi = (d[1:(n-2)]*d[2:(n-1)] > 0)
+  MiddleSiwithoutApplyingCondition = (L[1:(n-2)]*d[1:(n-2)]+L[2:(n-1)] * d[2:(n-1)]) / (L[1:(n-2)]+L[2:(n-1)])
+  sb = Conditionsi * MiddleSiwithoutApplyingCondition
+  # Judd (1998), page 234, Second Equation line plus 6.11.6 gives this array of slopes.
+  defaultEdgeGradients = c((3*d[1]-sb[1])/2, (3*d[n-1]-sb[n-2])/2)
+  edgeGradients[is.na(edgeGradients)] = defaultEdgeGradients[is.na(edgeGradients)]
+  gradients = c(edgeGradients[1] ,  sb,  edgeGradients[2])
+  return(gradients)
+}
+
+
+
 #' Create a Schumaker spline
 #' @export
 #' @param x A vector of x coordinates
@@ -25,7 +57,6 @@
 #' plot(xarray, Result, ylim=c(-0.5,2))
 #' lines(xarray, Result2, col = 2)
 #' lines(xarray, Result3, col = 3)
-
 Schumaker <- function(x,y, gradients = NA, Vectorised = TRUE, Extrapolation = c("Curve", "Constant", "Linear"), edgeGradients = c(NA,NA)){
   Extrapolation = Extrapolation[1]
   if (!(Extrapolation %in% c("Constant", "Linear", "Curve"))){stop("The extrapolation parameter defines what the function returns when evaluated
@@ -36,79 +67,68 @@ Schumaker <- function(x,y, gradients = NA, Vectorised = TRUE, Extrapolation = c(
 
 # Schumaker shape-preserving quadratic interpolation spline.
 
-n = length(x)
+  n = length(x)
 
-if (gradients[1] %in% c(NA,"Not-Supplied")){
-  # Judd (1998), page 233, second last equation
-  L = sqrt( (x[2:n]-x[1:(n-1)])^2 + (y[2:n]-y[1:(n-1)])^2)
-  # Judd (1998), page 233, last equation
-  d = (y[2:n]-y[1:(n-1)])/(x[2:n]-x[1:(n-1)])
-  # Judd (1998), page 234, Eqn 6.11.6
-  Conditionsi = (d[1:(n-2)]*d[2:(n-1)] > 0)
-  MiddleSiwithoutApplyingCondition = (L[1:(n-2)]*d[1:(n-2)]+L[2:(n-1)] * d[2:(n-1)]) / (L[1:(n-2)]+L[2:(n-1)])
-  sb = Conditionsi * MiddleSiwithoutApplyingCondition
-  # Judd (1998), page 234, Second Equation line plus 6.11.6 gives this array of slopes.
-  defaultEdgeGradients = c((3*d[1]-sb[1])/2, (3*d[n-1]-sb[n-2])/2)
-  edgeGradients[is.na(edgeGradients)] = defaultEdgeGradients[is.na(edgeGradients)]
-  gradients = c(edgeGradients[1] ,  sb,  edgeGradients[2])
-}
-
-NumberOfIntervalsWithKnots = 2*(n-1)
-
-Intervals = 1:(n-1)
-IntervalTab = data.frame(IntervalNum = sort(rep(Intervals,2)),
-                                    SubIntervalNum = rep(c(1,2),n-1),
-                                    StartOfInterval = numeric(NumberOfIntervalsWithKnots),
-                                    EndOfInterval = numeric(NumberOfIntervalsWithKnots)
-                                    )
-
-Evals = do.call(rbind, lapply(Intervals, function(IntervalNum) SchumakerIndInterval(c(y[IntervalNum], y[IntervalNum+1]), c(gradients[IntervalNum], gradients[IntervalNum+1]), c(x[IntervalNum], x[IntervalNum+1]))))
-
-IntervalTab = cbind(IntervalTab, Evals)
-rm(Evals)
-
-
-IntervalTab[IntervalTab$SubIntervalNum == 1, "StartOfInterval"] = x[1:n-1]
-IntervalTab[IntervalTab$SubIntervalNum == 2, "EndOfInterval"] = x[2:n]
-IntervalTab[IntervalTab$SubIntervalNum == 2, "StartOfInterval"] = IntervalTab$tsi[IntervalTab$SubIntervalNum == 2]
-IntervalTab[IntervalTab$SubIntervalNum == 1, "EndOfInterval"] = IntervalTab$tsi[IntervalTab$SubIntervalNum == 1]
-# This gets rid of empty intervals. The 1e-10 is there in case of numerical imprecision.
-IntervalTab <- IntervalTab[which(IntervalTab$EndOfInterval + 1e-10 > IntervalTab$StartOfInterval),]
-
-if ((Extrapolation %in% c("Constant", "Linear"))){
-  Botx = min(IntervalTab$StartOfInterval)
-  Boty   = y[1]
-
-  BotInt = findInterval(Botx, IntervalTab$StartOfInterval)
-  BotB = IntervalTab[BotInt ,c("B")]
-  BotC   = Boty - BotB
-
-    if (Extrapolation == "Constant"){
-
-      BotB = 0
-      BotC   = Boty
-    }
-
-  BotRow = data.frame(IntervalNum = 0, SubIntervalNum = 0, StartOfInterval = Botx-1, EndOfInterval = Botx, tsi = 0, C = 0, B =  BotB, A = BotC)
-
-
-  Topx = max(IntervalTab$EndOfInterval)
-  Topy   = y[n]
-
-  TopInt = findInterval(Topx, IntervalTab$StartOfInterval)
-
-  TopB = IntervalTab[TopInt ,c("B")]
-  TopC   = Topy
-
-  if (Extrapolation == "Constant"){
-    TopB = 0
-    TopC   = Topy
+  if (gradients[1] %in% c(NA,"Not-Supplied")){
+    gradients = impute_gradients(x,y, edgeGradients)
   }
 
-  TopRow = data.frame(IntervalNum = 0, SubIntervalNum = 0,StartOfInterval = Topx, EndOfInterval = Topx + 1, tsi = 0, C = 0, B =  TopB, A = TopC)
+  NumberOfIntervalsWithKnots = 2*(n-1)
 
-  IntervalTab = rbind(BotRow, IntervalTab, TopRow)
-}
+  Intervals = 1:(n-1)
+  IntervalTab = data.frame(IntervalNum = sort(rep(Intervals,2)),
+                                      SubIntervalNum = rep(c(1,2),n-1),
+                                      StartOfInterval = numeric(NumberOfIntervalsWithKnots),
+                                      EndOfInterval = numeric(NumberOfIntervalsWithKnots)
+                                      )
+
+  Evals = do.call(rbind, lapply(Intervals, function(IntervalNum) SchumakerIndInterval(c(y[IntervalNum], y[IntervalNum+1]), c(gradients[IntervalNum], gradients[IntervalNum+1]), c(x[IntervalNum], x[IntervalNum+1]))))
+
+  IntervalTab = cbind(IntervalTab, Evals)
+  rm(Evals)
+
+
+  IntervalTab[IntervalTab$SubIntervalNum == 1, "StartOfInterval"] = x[1:n-1]
+  IntervalTab[IntervalTab$SubIntervalNum == 2, "EndOfInterval"] = x[2:n]
+  IntervalTab[IntervalTab$SubIntervalNum == 2, "StartOfInterval"] = IntervalTab$tsi[IntervalTab$SubIntervalNum == 2]
+  IntervalTab[IntervalTab$SubIntervalNum == 1, "EndOfInterval"] = IntervalTab$tsi[IntervalTab$SubIntervalNum == 1]
+  # This gets rid of empty intervals. The 1e-10 is there in case of numerical imprecision.
+  IntervalTab <- IntervalTab[which(IntervalTab$EndOfInterval + 1e-10 > IntervalTab$StartOfInterval),]
+
+  if ((Extrapolation %in% c("Constant", "Linear"))){
+    Botx = min(IntervalTab$StartOfInterval)
+    Boty   = y[1]
+
+    BotInt = findInterval(Botx, IntervalTab$StartOfInterval)
+    BotB = IntervalTab[BotInt ,c("B")]
+    BotC   = Boty - BotB
+
+      if (Extrapolation == "Constant"){
+
+        BotB = 0
+        BotC   = Boty
+      }
+
+    BotRow = data.frame(IntervalNum = 0, SubIntervalNum = 0, StartOfInterval = Botx-1, EndOfInterval = Botx, tsi = 0, C = 0, B =  BotB, A = BotC)
+
+
+    Topx = max(IntervalTab$EndOfInterval)
+    Topy   = y[n]
+
+    TopInt = findInterval(Topx, IntervalTab$StartOfInterval)
+
+    TopB = IntervalTab[TopInt ,c("B")]
+    TopC   = Topy
+
+    if (Extrapolation == "Constant"){
+      TopB = 0
+      TopC   = Topy
+    }
+
+    TopRow = data.frame(IntervalNum = 0, SubIntervalNum = 0,StartOfInterval = Topx, EndOfInterval = Topx + 1, tsi = 0, C = 0, B =  TopB, A = TopC)
+
+    IntervalTab = rbind(BotRow, IntervalTab, TopRow)
+  }
 
   # It is important use individual vectors and matrices rather than datatables or data.frames for speed
   IntStarts = c(IntervalTab$StartOfInterval, Inf)
